# SCRS LaTeX Thesis Template

This template provides a scaffold for writing your thesis.
While typographical changes are generally possible, you are strongly encouraged to talk to your supervisor before "shipping" such a change - some settings have been chosen deliberately or might evoke strong feelings.

## Usage
- The template is currently setup for only `lualatex`, `biblatex` and `biber`. Other LaTeX engines and bibliography tools should generally work as well, but will probably require adjusting the preamble and/or class file. If you do this, let us know, so we can try to include your word, so that the next person does not have to do it as well ;)
- The compilation is orchestrated by `latexmk`.

### Generic Instructions
- Install a TeX distribution. Development currently happens under Debian / TeXLive
    - Debian and probably most Debian-based distributions: `apt install texlive-full` (all-inclusive service, but a big download/install! If you do not have the space, you need to identify the individual packages yourself - but feel free to let us know.)
- If you rename `writeup.tex`, also adjust `@default_files` in `latexmkrc` accordingly.
- To compile, just run `latexmk` in the directory of the main `.tex` file and the `latexmkrc` file. It will automatically compile as often as needed and run `biber` as well, when required.

### VSCodium / VS Code
- James-Yu's LaTex Workshop ([GitHub](https://github.com/James-Yu/LaTeX-Workshop), [Open VSX](https://open-vsx.org/extension/James-Yu/latex-workshop)) works great, to get it to compile with `latexmk` using `latexmkrc`, set `"latex-workshop.latex.recipe.default"` to `"latexmk (latexmkrc)"` (already set in the `.vscode/settings.json` included with the template)
- You might also want to use valentjin's LTeX – LanguageTool grammar/spell checking extension ([GitHub](https://github.com/valentjn/vscode-ltex), [Open VSX](https://open-vsx.org/extension/valentjn/vscode-ltex)) together with LanguageTool for type and grammar checking.

## Common Mistakes & Hints for a Good Thesis

### Graphics
- When referring to a figure, write `Figure 1`, with a capital letter `F` - even in the middle of a sentence. `\autoref{LABEL HERE}` can help you.
- When including drawings, plots, etc., include them as vector graphic (`eps`, `pdf`, ...) if at all possible (and reasonable).
    - Exporting a PDF from draw.io is not more complicated than exporting a raster image, but the result looks much better and stays sharp when zoomed in.
    - If possible with your plotting toolkit, you can also export your graphic as drawing commands for e.g. *pgf* - then with correct configuration the type face and font size will also match with the rest of the text. *Matplotlib* can do that, see its documentation [here](https://matplotlib.org/stable/users/explain/text/pgf.html). Note: This is typically more work and not strictly necessary.
    - A vector graphic is no longer reasonable if a recent computer takes a few seconds to render the resulting page. If the vector graphic is a plot, then with tools like *matplotlib* and *pgf*, it is possible to rasterize the plot lines while still keeping the axis, labels and legend as vector elements. If this is not easily possible, pre-render the graphic to a lossless raster format with sufficient resolution.
- Use raster images with lossless compression (`png`, ...) for screenshots and other images that were rastered in their original form.
- Use raster images with lossy compression (`jpeg`, ...) for pictures taken with a camera.

### Units and Quantities
- When writing quantities, use a package like `siunitx` (if possible) - then you don't have to deal with the typography yourself.
- Prefer quantity equations (equations that remain valid independent of the units, e.g. `\lambda = c / f`) and make sure the units work out. Avoid numerical-value equations (equations that depend on the quantities being expressed in specific units, e.g. `\lambda in m = 300 / f in MHz`). If numerical-value equations are required or very common, give the quantity equation beforehand.
- To label e.g. a column containing numeric values of a symbol, write `SYMBOL / UNIT`, or `SYMBOL in UNIT`, e.g. `SNR / dB`. The square brackets `[]` are used to indicate the unit of a symbol, e.g. `[SNR] = dB`. Ergo, `SNR [dB]` is nonsensical and wrong - even if commonly seen.
- More information about correctly dealing with units and equations can be found in the Rhode & Schwarz Brochure (in german, currently no other language version is known) [Der normgerechte Umgang mit Größen, Einheiten, und Gleichungen](https://scdn.rohde-schwarz.com/ur/pws/dl_downloads/pdm/cl_brochures_and_datasheets/brochure/5214_5061_61/Der_normgerechte_Umgang_mit_bro_de_5214-5061-61_v0600.pdf) ([IA](https://web.archive.org/web/20240304101932/https://scdn.rohde-schwarz.com/ur/pws/dl_downloads/pdm/cl_brochures_and_datasheets/brochure/5214_5061_61/Der_normgerechte_Umgang_mit_bro_de_5214-5061-61_v0600.pdf)) (Source: Search for *Einheiten* in the *Knowledge Center Downloads*)
    - Exception: `dBm` and friends are acceptable here, even if this document says these ITU abbreviations are to be avoided.


## Acknowledgements

Based on the Info 3 template - many thanks!
